.. contents::

Welcome to the WWTP Configuration package documentation!
========================================================

.. toctree::
   :maxdepth: 1
   :caption: Overview

   README <self>
   CONTRIBUTING
   LICENSE

.. toctree::
   :maxdepth: 1
   :caption: Class Hierarchy

   connection
   node
   tag

.. toctree::
   :maxdepth: 1
   :caption: JSON Parsing

   parse_json
   units

.. toctree::
   :maxdepth: 1
   :caption: Miscellaneous

   utils
   visualize

.. include:: ../README.rst

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
